@@ -18,9 +18,9 @@ use Mic::ArrayImpl
 sub push {
     my ($self, $val) = @_;
 
-    $self->[$Q]->push($val);
+    $self->[Q]->push($val);
 
-    if ($self->size > $self->[$MAX_SIZE]) {
+    if ($self->size > $self->[MAX_SIZE]) {
         $self->pop;        
     }
 }
