@@ -1,6 +1,6 @@
 package Example::Construction::Acme::Set_v2;
 
-use Mic::ArrayImpl
+use Mic::Impl
     has => { 
         SET => { 
             default => sub { {} },
@@ -11,24 +11,24 @@ use Mic::ArrayImpl
 sub BUILD {
     my ($self, $args) = @_;
 
-    $self->[$SET] = { map { $_ => 1 } @{ $args } };
+    $self->[SET] = { map { $_ => 1 } @{ $args } };
 }
 
 sub has {
     my ($self, $e) = @_;
 
-    exists $self->[$SET]{$e};
+    exists $self->[SET]{$e};
 }
 
 sub add {
     my ($self, $e) = @_;
 
-    ++$self->[$SET]{$e};
+    ++$self->[SET]{$e};
 }
 
 sub size {
     my ($self) = @_;
-    scalar(keys %{ $self->[$SET] });
+    scalar(keys %{ $self->[SET] });
 }
 
 1;
