@@ -11,23 +11,23 @@ Mic->define_class({
         class => { new => {} }
     },
 
-    implementation => 'Example::Usage::HashSet',
+    via => 'Example::Usage::HashSet',
 });
 
 package Example::Usage::HashSet;
 
-use Mic::Implementation
+use Mic::Impl
     has => { SET => { default => sub { {} } } },
 ;
 
 sub has {
     my ($self, $e) = @_;
-    exists $self->{$SET}{$e};
+    exists $self->[SET]{$e};
 }
 
 sub add {
     my ($self, $e) = @_;
-    ++$self->{$SET}{$e};
+    ++$self->[SET]{$e};
 }
 
 1;
